pub enum SPoly {
Standard(usize, usize),
Nilpotent(usize, usize),
}Available on crate feature
unstable-enable only.Expand description
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Variants
Implementations
Sourceimpl SPoly
impl SPoly
Sourcepub fn lcm_term<P, O>(
&self,
ring: P,
basis: &[El<P>],
order: O,
) -> (PolyCoeff<P>, PolyMonomial<P>)where
P: RingStore + Copy,
P::Type: MultivariatePolyRing,
<<P::Type as RingExtension>::BaseRing as RingStore>::Type: PrincipalLocalRing,
O: MonomialOrder + Copy,
pub fn lcm_term<P, O>(
&self,
ring: P,
basis: &[El<P>],
order: O,
) -> (PolyCoeff<P>, PolyMonomial<P>)where
P: RingStore + Copy,
P::Type: MultivariatePolyRing,
<<P::Type as RingExtension>::BaseRing as RingStore>::Type: PrincipalLocalRing,
O: MonomialOrder + Copy,
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn poly<P, O>(&self, ring: P, basis: &[El<P>], order: O) -> El<P>where
P: RingStore + Copy,
P::Type: MultivariatePolyRing,
<<P::Type as RingExtension>::BaseRing as RingStore>::Type: PrincipalLocalRing,
O: MonomialOrder + Copy,
pub fn poly<P, O>(&self, ring: P, basis: &[El<P>], order: O) -> El<P>where
P: RingStore + Copy,
P::Type: MultivariatePolyRing,
<<P::Type as RingExtension>::BaseRing as RingStore>::Type: PrincipalLocalRing,
O: MonomialOrder + Copy,
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.