Contains an implementation of computing convolutions by considering them modulo various primes that are either smaller or allow for suitable roots of unity.
Structs
- CreateNTT
Convolution unstable-enable - Function that creates an
NTTConvolutionwhen given a suitable modulus. - Prepared
Convolution Operand unstable-enable - A prepared convolution operand for a
RNSConvolution. - RNSConvolution
unstable-enable - A
ConvolutionAlgorithmthat computes convolutions by computing them modulo a suitable composite modulusq, whose factors are of a certain shape, usually such as to allow for NTT-based convolutions. - RNSConvolution
Zn unstable-enable - Same as
RNSConvolution, but computes convolutions overZnRings.