pub struct SubgroupBase<G: AbelianGroupStore> { /* private fields */ }unstable-enable only.Expand description
Represents a subgroup of an AbelianGroupBase by a set of generators.
Supports computing discrete logarithms, i.e. representing a given element
as a combination of the generators.
Note that the used algorithms have a worst case complexity of O(sqrt(ord^n))
where ord is the given multiple of the orders of each generator, and n
is the number of generators. However, if ord is smooth, much faster algorithms
are used.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations
Sourceimpl<G: AbelianGroupStore> SubgroupBase<G>
impl<G: AbelianGroupStore> SubgroupBase<G>
Sourcepub fn parent(&self) -> &G
pub fn parent(&self) -> &G
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn subgroup_order(&self) -> El<BigIntRing>
pub fn subgroup_order(&self) -> El<BigIntRing>
The number of elements in the subgroup generated by this generating set.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn order_multiple(&self) -> &El<BigIntRing>
pub fn order_multiple(&self) -> &El<BigIntRing>
Returns a multiple of the order of each element in the subgroup generated by this generating set.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn generators(&self) -> &[GroupEl<G>] ⓘ
pub fn generators(&self) -> &[GroupEl<G>] ⓘ
Returns a set of generators of this subgroup.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn add_generator(self, new_gen_base: GroupEl<G>) -> Self
pub fn add_generator(self, new_gen_base: GroupEl<G>) -> Self
Extends the generating set by an additional generator, which is likely to grow the represented subgroup.
The new generator must be of order dividing [GeneratingSet::order_multiple()].
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn contains(&self, element: &GroupEl<G>) -> bool
pub fn contains(&self, element: &GroupEl<G>) -> bool
Returns true if the given element is contained in this subgroup.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn dlog(&self, target: &GroupEl<G>) -> Option<Vec<i64>>
pub fn dlog(&self, target: &GroupEl<G>) -> Option<Vec<i64>>
Computes a discrete logarithm of target w.r.t. the stored set
if generators, or None if target is not in the subgroup generated by
these generators
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn rectangular_form<'a>(&'a self) -> Vec<(GroupEl<G>, usize)>
pub fn rectangular_form<'a>(&'a self) -> Vec<(GroupEl<G>, usize)>
Returns a list (g[i], l[i]) such that every element of the subgroup
can be uniquely written as prod_i g[i]^k[i] with 0 <= k[i] < l[i].
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn enumerate_elements<'a>(
&'a self,
) -> impl use<'a, G> + Clone + Iterator<Item = GroupEl<G>>
pub fn enumerate_elements<'a>( &'a self, ) -> impl use<'a, G> + Clone + Iterator<Item = GroupEl<G>>
Returns an iterator that yields every element contained in the subgroup exactly once.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.