eea

Function eea 

pub fn eea<R>(a: El<R>, b: El<R>, ring: R) -> (El<R>, El<R>, El<R>)
For a, b computes s, t, d such that s*a + t*b == d is a greatest common divisor of a and b.

The gcd d is only unique up to units, and s, t are not unique at all. No guarantees are given on which of these solutions is returned. For integers, see signed_eea() which gives more guarantees.

Note that this function always uses the euclidean algorithm to compute these values. In most cases, it is instead recommended to use PrincipalIdealRing::extended_ideal_gen(), which uses a ring-specific algorithm to compute the Bezout identity (which will of course be eea() in some cases).