Module linsolve

Modules

extension
Contains the algorithm for solving linear systems over free ring extensions.
smith
Contains the algorithm to compute the “pre-smith” form of a matrix, which is sufficient for solving linear systems. Works over all principal ideal rings.

Enums

SolveResult
Result of trying to solve a linear system.

Traits

LinSolveRing
Class for rings over which we can solve linear systems.
LinSolveRingStore
RingStore corresponding to LinSolveRing.