Module smith

Module smith 

Contains the algorithm to compute the “pre-smith” form of a matrix, which is sufficient for solving linear systems. Works over all principal ideal rings.

Functions

determinant_using_pre_smithunstable-enable
Availability
kernel_basis_using_pre_smithunstable-enable
Computes a basis of the right-kernel of the matrix A, i.e. a full-rank matrix B such that AB = 0 and every x with Ax = 0 is of the form x = By for some y.
pre_smithunstable-enable
Transforms A into A' via transformations L, R such that L A R = A' and A' is diagonal.
solve_right_using_pre_smithunstable-enable
Computes a matrix X such that lhs * X = rhs, if it exists.