Contains poly_gcd::PolyTFracGCDRing for rings over which we can compute polynomial gcds and
related operations, modulo multiplication by non-zero divisors.
Modules
- finite
- Contains an implementation of factoring polynomials over finite fields.
- gcd
- Contains algorithms for computing the gcd of polynomials.
- hensel
- Contains an implementation of Hensel lifting, to lift a factorization modulo a maximal ideal to a factorization modulo a power of this ideal.
- squarefree_
part - Contains algorithms for computing power decompositions and the square-free part of polynomials.
Traits
- PolyT
FracGCD Ring - Trait for domain
Rfor which there is an efficient way of computing the gcd of univariate polynomials overTFrac(R), whereTFrac(R)is the total ring of fractions.
Functions
- evaluate_
aX unstable-enable - Computes the map
- make_
primitive unstable-enable - Given a polynomial
fover a PID, returns(f/cont(f), cont(f)), wherecont(f)is the content off, i.e. the gcd of all coefficients off. - poly_
root unstable-enable - Checks whether there exists a polynomial
gsuch thatg^k = f, and if yes, returnsg. - unevaluate_
aX unstable-enable - Computes the inverse to
evaluate_aX().