Contains algorithms to find roots of unity in finite fields.
Functions
- get_
prim_ root_ of_ unity - Returns a primitive
n-th root of unity in the given finite field, orNone, if the order of the multiplicative group of the field is not divisible byn. - get_
prim_ root_ of_ unity_ gen unstable-enable - Availability
- get_
prim_ root_ of_ unity_ pow2 - Returns a primitive
2^log2_n-th root of unity in the given finite field, orNone, if the order of the multiplicative group of the field is not divisible by2^log2_n. - get_
prim_ root_ of_ unity_ pow2_ zn unstable-enable - Returns a primitive
n-th root of unity in the given ringZ/kZ, orNone, if the order of the multiplicative group of the field is not divisible byn. - get_
prim_ root_ of_ unity_ zn unstable-enable - Returns a primitive
n-th root of unity in the given ringZ/kZ, orNone, if the order of the multiplicative group of the field is not divisible byn. - get_
prim_ root_ of_ unity_ zn_ gen unstable-enable - Availability
- is_
prim_ root_ of_ unity unstable-enable - Availability
- is_
prim_ root_ of_ unity_ gen unstable-enable - Availability
- is_
prim_ root_ of_ unity_ pow2 unstable-enable - Availability
- is_
root_ of_ unity unstable-enable - Availability
- is_
root_ of_ unity_ gen unstable-enable - Availability