WrapHom

Struct WrapHom 

pub struct WrapHom<R, S>
where R: RingStore, S::Type: DelegateRing<Base = R::Type>, S: RingStore,
{ /* private fields */ }
Homomorphism from a ring to a DelegateRing with the former ring as delegate target. An element is mapped by using DelegateRing::rev_delegate().

Implementations

Source

impl<R, S> WrapHom<R, S>
where R: RingStore, S::Type: DelegateRing<Base = R::Type>, S: RingStore,

pub fn new(from: R, to: S) -> Self

Creates a new WrapHom between the given rings.

Source

impl<'a, R> WrapHom<RingRef<'a, R::Base>, RingRef<'a, R>>
where R: ?Sized + DelegateRing,

pub fn to_delegate_ring(to: &'a R) -> Self

Creates a new WrapHom from the given ring’s delegate target to the given ring.

This function must take to by reference, since it must be able to obtain a reference to its delegate target that lives long enough.