pub trait DelegateRingImplFiniteRing: DelegateRing { }Expand description
Marks a DelegateRing R to be considered in the blanket implementation
R: FiniteRing where R::Base: FiniteRing.
We don’t want to implement R: FiniteRing for any DelegateRing R, since
some ring newtypes want to have control of when the ring is FiniteRing.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.