pub struct PreparedDivisor<R>{
pub element: R::Element,
pub data: R::PreparedDivisorData,
}Expand description
Struct for ring elements that are stored with associated data to enable faster divisions.
For details, see DivisibilityRing::prepare_divisor().
Fields
element: R::ElementThis PreparedDivisor can perform the division by this element
data: R::PreparedDivisorDataAdditional data used to compute the division by the stored element more efficiently
Implementations
Sourceimpl<R> PreparedDivisor<R>
impl<R> PreparedDivisor<R>
Sourcepub fn new(ring: &R, el: R::Element) -> Self
pub fn new(ring: &R, el: R::Element) -> Self
Creates a new PreparedDivisor from the given ring element, obtaining
any additional data by calling DivisibilityRing::prepare_divisor().
Sourcepub fn checked_left_div_by(
&self,
lhs: &R::Element,
ring: &R,
) -> Option<R::Element>
pub fn checked_left_div_by( &self, lhs: &R::Element, ring: &R, ) -> Option<R::Element>
Computes some q such that q * self == lhs, if it exists.
If the underlying ring supports it, this uses precomputed data
and thus can be faster than DivisibilityRing::checked_left_div().