Module field

Module field 

Contains the trait field::Field for rings that are fields.

Modules

generic_testsgeneric_tests

Traits

Field
Trait for rings that are fields, i.e. where every nonzero element has an inverse.
FieldStore
Trait for RingStores that store Fields. Mainly used to provide a convenient interface to the Field-functions.
PerfectField
Field such that every finite degree extension field is separable.