Module group

Module group 

Contains the traits group::AbelianGroupBase and group::AbelianGroupStore, which (in analogue to ring::RingBase and ring::RingStore) model groups. These are much less central to this library than the ring traits, however.

Structs

AddGroupBaseunstable-enable
The additive group of a ring, implements AbelianGroupBase.
DeserializeWithGroupunstable-enable
Wrapper of a group that implements [serde::DeserializationSeed] by trying to deserialize an element w.r.t. the wrapped group.
GroupValueunstable-enable
Analogue of RingValue for groups.
HashableGroupElunstable-enable
Availability
MultGroupBaseunstable-enable
The multiplicative group of a ring, implements AbelianGroupBase.
MultGroupElunstable-enable
Elements from the multiplicative group of R.
SerializeOwnedWithGroupunstable-enable
Wraps a ring and a one of its elements. Implements serde::Serialize and will serialize the element w.r.t. the ring.
SerializeWithGroupunstable-enable
Wraps a group and a reference to one of its elements. Implements serde::Serialize and will serialize the element w.r.t. the group.

Traits

AbelianGroupBaseunstable-enable
Trait for implementations of generic abelian groups, for which only the group operation, equality testing and computing hash values is supported.
AbelianGroupStoreunstable-enable
Object provides access to a generic abelian group, as modelled by AbelianGroupBase.
SerializableElementGroupunstable-enable
Trait for rings whose elements can be serialized.

Type Aliases

AddGroupunstable-enable
AbelianGroupStore corresponding to AddGroupBase.
GroupElunstable-enable
Alias for the type of elements of a group underlying an AbelianGroupStore.
MultGroupunstable-enable
AbelianGroupStore corresponding to MultGroupBase.