pub struct DeserializeWithGroup<G: AbelianGroupStore>where
G::Type: SerializableElementGroup,{ /* private fields */ }Available on crate feature
unstable-enable only.Expand description
Wrapper of a group that implements [serde::DeserializationSeed] by trying to deserialize
an element w.r.t. the wrapped group.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations
Sourceimpl<G> DeserializeWithGroup<G>
impl<G> DeserializeWithGroup<G>