pub struct SerializeOwnedWithGroup<G: AbelianGroupStore>where
G::Type: SerializableElementGroup,{ /* private fields */ }Available on crate feature
unstable-enable only.Expand description
Wraps a ring and a one of its elements. Implements serde::Serialize and
will serialize the element w.r.t. the ring.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations
Sourceimpl<G: AbelianGroupStore> SerializeOwnedWithGroup<G>where
G::Type: SerializableElementGroup,
impl<G: AbelianGroupStore> SerializeOwnedWithGroup<G>where
G::Type: SerializableElementGroup,