AddGroup

Type Alias AddGroup 

pub type AddGroup<R: RingStore> = GroupValue<AddGroupBase<R>>;
Available on crate feature unstable-enable only.
AbelianGroupStore corresponding to AddGroupBase.

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Aliased Type

pub struct AddGroup<R: RingStore> { /* private fields */ }

Implementations

Source

impl<R: RingStore> AddGroup<R>
where R::Type: HashableElRing,

pub fn new(ring: R) -> Self

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.