GroupEl

Type Alias GroupEl 

pub type GroupEl<G: AbelianGroupStore> = <G::Type as AbelianGroupBase>::Element;
Available on crate feature unstable-enable only.
Alias for the type of elements of a group underlying an AbelianGroupStore.

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.