MultGroup

Type Alias MultGroup 

pub type MultGroup<R: RingStore> = GroupValue<MultGroupBase<R>>;
Available on crate feature unstable-enable only.
AbelianGroupStore corresponding to MultGroupBase.

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Aliased Type

pub struct MultGroup<R: RingStore> { /* private fields */ }

Implementations

Source

impl<R: RingStore> MultGroup<R>

pub fn new(ring: R) -> Self

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn underlying_ring(&self) -> &R

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn from_ring_el(&self, x: El<R>) -> Option<MultGroupEl<R>>

If x is contained in R*, returns a MultGroupEl representing x. Otherwise, None is returned.

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn as_ring_el<'a>(&self, x: &'a MultGroupEl<R>) -> &'a El<R>

Returns the ring element represented by the given group element.

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.