CanHomRef

Struct CanHomRef 

pub struct CanHomRef<'a, R, S>
where R: RingStore, S: RingStore, S::Type: CanHomFrom<R::Type>,
{ /* private fields */ }
Available on crate feature unstable-enable only.
A wrapper of CanHomFrom::Homomorphism that does not own the data associated with the homomorphism. Use cases are rare, prefer to use CanHom whenever possible.

More concretely, this should only be used when you only have a reference to <R as CanHomFrom<S>>::Homomorphism, but cannot refactor code to wrap that object in a CanHom instead. The main situation where this occurs is when implementing CanHomFrom, since a the lifetime of CanHom is bound by the lifetime of the domain and codomain rings, but CanHomFrom::Type does not allow this.

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl<'a, R, S> CanHomRef<'a, R, S>
where R: RingStore, S: RingStore, S::Type: CanHomFrom<R::Type>,

pub fn raw_hom(&self) -> &<S::Type as CanHomFrom<R::Type>>::Homomorphism

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn from_raw_parts( from: R, to: S, data: &'a <S::Type as CanHomFrom<R::Type>>::Homomorphism, ) -> Self

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.