LambdaHom

Struct LambdaHom 

pub struct LambdaHom<R: RingStore, S: RingStore, F>
where F: Fn(&R, &S, &El<R>) -> El<S>,
{ /* private fields */ }
A homomorphism between rings R -> S, with its action on elements defined by a user-provided closure.

It is up to the user to ensure that the given closure indeed satisfies the ring homomorphism axioms:

  • For x, y in R, it should satisfy f(x) + f(y) = f(x + y)
  • For x, y in R, it should satisfy f(x) * f(y) = f(x * y)
  • It should map f(0) = 0 and f(1) = 1

Hence, a LambdaHom should only be used if none of the builtin homomorphisms can achieve the same result, since a function that does not follow the above axioms will make algorithms misbehave, and can lead to hard-to-debug errors.

Implementations

Source

impl<R: RingStore, S: RingStore, F> LambdaHom<R, S, F>
where F: Fn(&R, &S, &El<R>) -> El<S>,

pub fn new(from: R, to: S, f: F) -> Self

Creates a new LambdaHom from from to to, mapping elements as specified by the given function.

It is up to the user to ensure that the given closure indeed satisfies the ring homomorphism axioms:

  • For x, y in R, it should satisfy f(x) + f(y) = f(x + y)
  • For x, y in R, it should satisfy f(x) * f(y) = f(x * y)
  • It should map f(0) = 0 and f(1) = 1

Hence, a LambdaHom should only be used if none of the builtin homomorphisms can achieve the same result, since a function that does not follow the above axioms will make algorithms misbehave, and can lead to hard-to-debug errors.

pub fn into_domain_codomain(self) -> (R, S)

Available on crate feature unstable-enable only.

Returns the stored domain and codomain rings, consuming this object.

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.