Type Alias BigIntRingBase

pub type BigIntRingBase = MPZBase;
Type alias for the current default used big integer ring implementation.

The type this points to may change when features or other compilation parameters change.

Aliased Type

struct BigIntRingBase;