basic_powerset

Function basic_powerset 

pub fn basic_powerset<I>(it: I) -> impl Iterator<Item = Box<[I::Item]>>
where I: Iterator + Clone, I::Item: Clone,
Returns an iterator over all subsets of the elements returned by the given iterator.

This is a special version of powerset(), which accepts a converter function and thus can avoid cloning each subset.