macro_rules! default_memory_provider {
    () => { ... };
}
Returns an instance of the current default memory provider.

The used memory provider can change depending on enabled features and conditional compilation.