pub fn format_matrix<'a, M, R>(
row_count: usize,
col_count: usize,
matrix: M,
ring: R,
) -> impl 'a + DisplayAvailable on crate feature
unstable-enable only.Expand description
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.