Struct feanor_math::matrix::submatrix::AsFirstElement
source · pub struct AsFirstElement<T>(/* private fields */);Expand description
Represents a contiguous batch of Ts by their first element.
In other words, a pointer to the batch is equal to a pointer to
the first value.