Module transform

Structs

TransformCols
Wraps a SubmatrixMut to get a TransformTarget. Every transform is multiplied to the wrapped matrix from the right, i.e. applied to the cols of the matrix.
TransformList
Availability
TransformRows
Wraps a SubmatrixMut to get a TransformTarget. Every transform is multiplied to the wrapped matrix from the left, i.e. applied to the rows of the matrix.

Traits

TransformTarget
A trait for a “target” that can “consume” elementary operations on matrices.