Module feanor_math::ordered

source ·
Contains the trait ordered::OrderedRing for rings with a total ordering that is compatible with the ring operations.

Traits

  • Trait for rings that have a total ordering on their elements. The ordering must be compatible with addition and multiplication in the usual sense.
  • Trait for RingStores that store OrderedRings. Mainly used to provide a convenient interface to the OrderedRing-functions.