Module pid

Module pid 

Contains the trait pid::PrincipalIdealRing for rings in whom every ideal is principal. Also contains pid::EuclideanRing, which is the simplest way how a ring can become a principal idea ring.

Modules

generic_testsgeneric_tests

Traits

EuclideanRing
Trait for rings that support euclidean division.
EuclideanRingStore
RingStore for EuclideanRings
PrincipalIdealRing
Trait for rings that are principal ideal rings, i.e. every ideal is generated by a single element.
PrincipalIdealRingStore
Trait for RingStores that store PrincipalIdealRings. Mainly used to provide a convenient interface to the PrincipalIdealRing-functions.