pub struct PolyGCDLocallyIntermediateReductionMap<'ring, 'data, 'local, R>where
R: 'ring + ?Sized + PolyGCDLocallyDomain,
'ring: 'data,{ /* private fields */ }unstable-enable only.Expand description
The map R/m^r -> R/m^e, where r > e and m is a maximal ideal factor of the
ideal I, as specified by PolyGCDLocallyDomain.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations
Sourceimpl<'ring, 'data, 'local, R> PolyGCDLocallyIntermediateReductionMap<'ring, 'data, 'local, R>where
R: 'ring + ?Sized + PolyGCDLocallyDomain,
'ring: 'data,
impl<'ring, 'data, 'local, R> PolyGCDLocallyIntermediateReductionMap<'ring, 'data, 'local, R>where
R: 'ring + ?Sized + PolyGCDLocallyDomain,
'ring: 'data,
Sourcepub fn new(
ring: &'data R,
ideal: &'data R::SuitableIdeal<'ring>,
from: &'local R::LocalRing<'ring>,
from_e: usize,
to: &'local R::LocalRing<'ring>,
to_e: usize,
max_ideal_idx: usize,
) -> Self
pub fn new( ring: &'data R, ideal: &'data R::SuitableIdeal<'ring>, from: &'local R::LocalRing<'ring>, from_e: usize, to: &'local R::LocalRing<'ring>, to_e: usize, max_ideal_idx: usize, ) -> Self
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn parent_ring<'a>(&'a self) -> RingRef<'a, R>
pub fn parent_ring<'a>(&'a self) -> RingRef<'a, R>
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn from_e(&self) -> usize
pub fn from_e(&self) -> usize
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn to_e(&self) -> usize
pub fn to_e(&self) -> usize
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn ideal<'a>(&'a self) -> &'a R::SuitableIdeal<'ring>
pub fn ideal<'a>(&'a self) -> &'a R::SuitableIdeal<'ring>
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn max_ideal_idx(&self) -> usize
pub fn max_ideal_idx(&self) -> usize
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.