RingExtensionStore

Trait RingExtensionStore 

pub trait RingExtensionStore: RingStore
where Self::Type: RingExtension,
{ // Provided methods fn base_ring(&self) -> &<Self::Type as RingExtension>::BaseRing { ... } fn into_inclusion(self) -> Inclusion<Self> { ... } fn inclusion<'a>(&'a self) -> Inclusion<&'a Self> { ... } }
Provided Methods

fn base_ring(&self) -> &<Self::Type as RingExtension>::BaseRing

fn into_inclusion(self) -> Inclusion<Self>

Returns the inclusion map of the base ring R -> self.

fn inclusion<'a>(&'a self) -> Inclusion<&'a Self>

Returns the inclusion map of the base ring R -> self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors