pub struct Real64Base;Expand description
An approximate implementation of the real numbers R, using 64 bit floating
point numbers.
Warning
Since floating point numbers do not exactly represent the real numbers, and this crate follows
a mathematically precise approach, we cannot provide any function related to equality.
In particular, Real64Base.eq_el(a, b) is not supported, and will panic.
Hence, this ring has only limited use within this crate, and is currently only used for
floating-point FFTs and some approximate computations in the LLL algorithm.
Implementations
Sourceimpl Real64Base
impl Real64Base
pub fn is_absolute_approx_eq( &self, lhs: <Self as RingBase>::Element, rhs: <Self as RingBase>::Element, absolute_threshold: f64, ) -> bool
pub fn is_relative_approx_eq( &self, lhs: <Self as RingBase>::Element, rhs: <Self as RingBase>::Element, relative_threshold: f64, ) -> bool
pub fn is_approx_eq( &self, lhs: <Self as RingBase>::Element, rhs: <Self as RingBase>::Element, precision: u64, ) -> bool