Module float_complex

Module float_complex 

An approximate implementation of the field of complex numbers C, using 64-bit floating point numbers.

Structs

Complex64Base
An approximate implementation of the complex numbers C, using 64 bit floating point numbers.
Complex64El
An element of Complex64.

Type Aliases

Complex64
RingStore corresponding to Complex64Base