pub struct MPZBase;mpir only.Expand description
Arbitrary-precision integer ring, implemented by binding to the well-known and heavily optimized library mpir (fork of gmp).
TODO: Remove Copy at next breaking release.
Implementations
Sourceimpl MPZBase
impl MPZBase
Sourcepub fn from_le_bytes(&self, dst: &mut MPZEl, input: &[u8])
pub fn from_le_bytes(&self, dst: &mut MPZEl, input: &[u8])
Interprets the bytes in input as little endian bytes and returns the
nonnegative integer represented by them.
Sourcepub fn from_base_u64_repr(&self, dst: &mut MPZEl, input: &[u64])
pub fn from_base_u64_repr(&self, dst: &mut MPZEl, input: &[u64])
Interprets the u64 as digits w.r.t. base 2^64 (with least-significant digit first)
and returns the nonnegative integer represented by them.
pub fn abs_base_u64_repr_len(&self, src: &MPZEl) -> usize
Sourcepub fn abs_base_u64_repr(&self, src: &MPZEl, out: &mut [u64])
pub fn abs_base_u64_repr(&self, src: &MPZEl, out: &mut [u64])
Inverse to MPZBase::from_base_u64_repr().
pub fn to_le_bytes_len(&self, src: &MPZEl) -> usize
Sourcepub fn to_le_bytes(&self, src: &MPZEl, out: &mut [u8])
pub fn to_le_bytes(&self, src: &MPZEl, out: &mut [u8])
Inverse to MPZBase::from_le_bytes().