DegRevLex

Struct DegRevLex 

pub struct DegRevLex;
The graded reverse lexicographic order. This is the most important monomial order, since computing a Groebner basis w.r.t. this order is usually more efficient than for other orders. Also sometimes referred to as “grevlex”.

Concretely, this is the ordering of monomials we get by first comparing monomial degrees, and in case of a tie reverse the outcome of a lexicographic comparison, using a reversed order of variables.

Example

let poly_ring = MultivariatePolyRingImpl::new(StaticRing::<i64>::RING, 3);
let monomials_descending = [
    [2, 0, 0], // x1^2
    [1, 1, 0], // x1 x2
    [0, 2, 0], // x2^2
    [1, 0, 1], // x1 x3
    [0, 1, 1], // x2 x3
    [0, 0, 2], // x3^2
].into_iter().map(|m| poly_ring.create_monomial(m)).collect::<Vec<_>>();
for i in 1..6 {
    assert!(DegRevLex.compare(&poly_ring, &monomials_descending[i - 1], &monomials_descending[i]) == Ordering::Greater);
}