DensePolyRingBase

Struct DensePolyRingBase 

pub struct DensePolyRingBase<R: RingStore, A: Allocator + Clone = Global, C: ConvolutionAlgorithm<R::Type> = KaratsubaAlgorithm<Global>> { /* private fields */ }
The univariate polynomial ring R[X]. Polynomials are stored as dense vectors of coefficients, allocated by the given memory provider.

If most of the coefficients will be zero, consider using sparse_poly::SparsePolyRingBase instead for improved performance.

Example

let ZZ = StaticRing::<i32>::RING;
let P = DensePolyRing::new(ZZ, "X");
let x_plus_1 = P.add(P.indeterminate(), P.int_hom().map(1));
let binomial_coefficients = P.pow(x_plus_1, 10);
assert_eq!(10 * 9 * 8 * 7 * 6 / 120, *P.coefficient_at(&binomial_coefficients, 5));

This ring has a CanIsoFromTo to sparse_poly::SparsePolyRingBase.

let ZZ = StaticRing::<i32>::RING;
let P = DensePolyRing::new(ZZ, "X");
let P2 = SparsePolyRing::new(ZZ, "X");
let high_power_of_x = P.pow(P.indeterminate(), 10);
assert_el_eq!(P2, P2.pow(P2.indeterminate(), 10), &P.can_iso(&P2).unwrap().map(high_power_of_x));

Implementations

Source

impl<R: RingStore, A: Allocator + Clone, C: ConvolutionAlgorithm<R::Type>> DensePolyRingBase<R, A, C>

pub fn into_base_ring(self) -> R

Available on crate feature unstable-enable only.
Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.