RationalFieldBase

Struct RationalFieldBase 

pub struct RationalFieldBase<I: RingStore>
where I::Type: IntegerRing,
{ /* private fields */ }
An implementation of the rational number Q, based on representing them as a tuple (numerator, denominator).

Be careful when instantiating it with finite-precision integers, like StaticRing<i64>, since by nature of the rational numbers, both numerator and denominator can increase dramatically, even when the numbers itself are of moderate size.

Example

let ZZ = StaticRing::<i64>::RING;
let QQ = RationalField::new(ZZ);
let hom = QQ.can_hom(&ZZ).unwrap();
let one_half = QQ.div(&QQ.one(), &hom.map(2));
assert_el_eq!(QQ, QQ.div(&QQ.one(), &hom.map(4)), QQ.pow(one_half, 2));

You can also retrieve numerator and denominator.

assert_el_eq!(ZZ, ZZ.int_hom().map(1), QQ.num(&one_half));
assert_el_eq!(ZZ, ZZ.int_hom().map(2), QQ.den(&one_half));

Implementations

Source

impl<I> RationalFieldBase<I>
where I: RingStore, I::Type: IntegerRing,

pub fn num<'a>(&'a self, el: &'a <Self as RingBase>::Element) -> &'a El<I>

The numerator of the fully reduced fraction.

Example
assert_el_eq!(ZZ, 2, QQ.num(&QQ.div(&QQ.inclusion().map(6), &QQ.inclusion().map(3))));
pub fn den<'a>(&'a self, el: &'a <Self as RingBase>::Element) -> &'a El<I>

The denominator of the fully reduced fraction.

Example
assert_el_eq!(ZZ, 3, QQ.den(&QQ.div(&QQ.inclusion().map(3), &QQ.inclusion().map(9))));