pub struct RustBigint<A: Allocator = Global>(/* private fields */);Expand description
An element of the integer ring implementation RustBigintRing.
An object of this struct does represent an arbitrary-precision integer,
but it follows the general approach of feanor-math to expose its actual
behavior through the ring, and not through the elements. For example, to
add integers, use
const ZZ: RustBigintRing = RustBigintRing::RING;
let a: RustBigint = ZZ.add(ZZ.power_of_two(50), ZZ.power_of_two(100));
assert_eq!("1267650600228230527396610048000", format!("{}", ZZ.format(&a)));and not
ⓘ
assert_eq!("1267650600228230527396610048000", format!("{}", RustBigint::from(2).pow(100) + RustBigint::from(2).pow(50)));Trait Implementations
Sourceimpl<A: Clone + Allocator> Clone for RustBigint<A>
impl<A: Clone + Allocator> Clone for RustBigint<A>
Sourcefn clone(&self) -> RustBigint<A>
fn clone(&self) -> RustBigint<A>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<A> Freeze for RustBigint<A>where
A: Freeze,
impl<A> RefUnwindSafe for RustBigint<A>where
A: RefUnwindSafe,
impl<A> Send for RustBigint<A>where
A: Send,
impl<A> Sync for RustBigint<A>where
A: Sync,
impl<A> Unpin for RustBigint<A>where
A: Unpin,
impl<A> UnwindSafe for RustBigint<A>where
A: UnwindSafe,