ZnReductionMap

Struct ZnReductionMap 

pub struct ZnReductionMap<R, S>
where R: RingStore, R::Type: ZnRing, S: RingStore, S::Type: ZnRing,
{ /* private fields */ }
The homomorphism Z/nZ -> Z/mZ that exists whenever m | n. In addition to the map, this also provides a function ZnReductionMap::smallest_lift() that computes the “smallest” preimage under the map, and a function ZnReductionMap::mul_quotient_fraction(), that computes the multiplication with n/m while also changing from Z/mZ to Z/nZ. This is very useful in many number theoretic applications, where one often has to switch between Z/nZ and Z/mZ.

Furthermore, many implementations of ZnRing currently do not support CanHomFrom-homomorphisms when the moduli are different (but divide each other).

Implementations

Source

impl<R, S> ZnReductionMap<R, S>
where R: RingStore, R::Type: ZnRing, S: RingStore, S::Type: ZnRing,

pub fn new(from: R, to: S) -> Option<Self>

pub fn mul_quotient_fraction(&self, x: El<S>) -> El<R>

Computes the additive group homomorphism Z/mZ -> Z/nZ, x -> (n/m)x.

Example
let Z5 = Zn::new(5);
let Z25 = Zn::new(25);
let f = ZnReductionMap::new(&Z25, &Z5).unwrap();
assert_el_eq!(Z25, Z25.int_hom().map(15), f.mul_quotient_fraction(Z5.int_hom().map(3)));
pub fn smallest_lift(&self, x: El<S>) -> El<R>

Computes the smallest preimage under the reduction map Z/nZ -> Z/mZ, where “smallest” refers to the element that has the smallest lift to Z.

Example
let Z5 = Zn::new(5);
let Z25 = Zn::new(25);
let f = ZnReductionMap::new(&Z25, &Z5).unwrap();
assert_el_eq!(Z25, Z25.int_hom().map(-2), f.smallest_lift(Z5.int_hom().map(3)));
pub fn any_preimage(&self, x: El<S>) -> El<R>

pub fn smallest_lift_ref(&self, x: &El<S>) -> El<R>