permute_inv_using_allocator

Function permute_inv_using_allocator 

pub fn permute_inv_using_allocator<V, T, F, A: Allocator>(
    values: V,
    perm: F,
    allocator: A,
)
where V: SwappableVectorViewMut<T>, F: Fn(usize) -> usize,
Available on crate feature unstable-enable only.
Computes values_new[perm(i)] = values[i]. This is the inverse operation to permute().

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.