Module generic_tests

Module generic_tests 

Available on crate feature unstable-enable only.
Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Functions

test_serialization
Availability
test_serialize_deserialize
Availability