test_serialization

Function test_serialization 

pub fn test_serialization<R: RingStore, I: Iterator<Item = El<R>>>(
    ring: R,
    edge_case_elements: I,
)
Available on crate feature unstable-enable only.
Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.