test_serialize_deserialize

Function test_serialize_deserialize 

pub fn test_serialize_deserialize<T: Serialize + for<'de> Deserialize<'de> + PartialEq>(
    x: T,
)
Available on crate feature unstable-enable only.
Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.