pub struct SerializableSeq<V, T>where
V: VectorFn<T>,{ /* private fields */ }Expand description
Wraps a VectorFn whose elements are Serializeable, and
allows to serialize all elements as a sequence.
To deserialize, consider using DeserializeSeedSeq.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations