Struct feanor_math::wrapper::RingElementWrapper

source ·
pub struct RingElementWrapper<R>
where R: RingStore,
{ /* private fields */ }
Stores a ring element together with its ring, so that ring operations do not require explicit mention of the ring object. This can be used both for convenience of notation (i.e. use a + b instead of ring.add(a, b)) and might also be necessary when e.g. storing elements in a set.

Examples

 
let ring = DensePolyRing::new(StaticRing::<i64>::RING, "X");
let x = RingElementWrapper::new(&ring, ring.indeterminate());
println!("The result is: {}", x.clone() + x.clone() * x);
// instead of
let x = ring.indeterminate();
println!("The result is: {}", ring.format(&ring.add(ring.mul(ring.clone_el(&x), ring.clone_el(&x)), ring.clone_el(&x))));

Implementations

source

impl<R: RingStore> RingElementWrapper<R>

source

pub const fn new(ring: R, element: El<R>) -> Self

source

pub fn pow(self, power: usize) -> Self

source

pub fn unwrap(self) -> El<R>