pub fn test_prepared_convolution<C, R>(convolution: C, ring: R, scale: El<R>)Expand description
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.