Module rns

Structs

CreateNTTConvolution
Function that creates an NTTConvolution when given a suitable modulus.
PreparedConvolutionOperand
A prepared convolution operand for a RNSConvolution.
PreparedConvolutionOperandZn
A prepared convolution operand for a RNSConvolutionZn.
RNSConvolution
A ConvolutionAlgorithm that computes convolutions by computing them modulo a suitable composite modulus q, whose factors are of a certain shape, usually such as to allow for NTT-based convolutions.
RNSConvolutionZn
Same as RNSConvolution, but computes convolutions over ZnRings.