Modules
- extension
- Contains the algorithm for solving linear systems over free ring extensions.
- smith
- Contains the algorithm to compute the “pre-smith” form of a matrix, which is sufficient for solving linear systems. Works over all principal ideal rings.
Enums
- Solve
Result - Result of trying to solve a linear system.
Traits
- LinSolve
Ring - Class for rings over which we can solve linear systems.
- LinSolve
Ring Store RingStorecorresponding toLinSolveRing.