Contains poly_div::poly_div_rem() for computing polynomial division. In most cases,
you will instead use this functionality through crate::pid::EuclideanRing::euclidean_div_rem().
Enums
- Poly
DivRem Reduced Error unstable-enable - Possible errors that might be returned by
poly_div_rem_finite_reduced().
Functions
- fast_
poly_ div_ rem - Computes the polynomial division of
lhsbyrhs, i.e.lhs = q * rhs + rwithdeg(r) < deg(rhs), i.e. is functionally equivalent topoly_div_rem(). - poly_
checked_ div_ finite_ reduced unstable-enable - Checks whether
rhs | lhsand returns a quotient if one exists, assuming that the base ring is reduced. If it is not, the function may fail with a nilpotent element of the base ring. - poly_
div_ rem unstable-enable - Computes the polynomial division of
lhsbyrhs, i.e.lhs = q * rhs + rwithdeg(r) < deg(rhs). - poly_
div_ rem_ domain unstable-enable - Computes
(q, r, a)such thata * lhs = q * rhs + randdeg(r) < deg(rhs). The chosen factorais in the base ring and is the smallest possible w.r.t. divisibility. - poly_
div_ rem_ finite_ reduced unstable-enable - Given polynomials
f, gover a finite and reduced ringR, tries to compute the polynomial division offbyg, i.e. valuesq, r in R[X]withf = q g + randdeg(r) < deg(g).