Contains the trait delegate::DelegateRing that simplifies implementing the
newtype-pattern for rings.
Structs
- Delegate
Finite Ring Elements Iter - Iterator over all elements of a finite
DelegateRing. - Unwrap
Hom - Homomorphism from a
DelegateRingto its delegate target. An element is mapped by usingDelegateRing::delegate(). - WrapHom
- Homomorphism from a ring to a
DelegateRingwith the former ring as delegate target. An element is mapped by usingDelegateRing::rev_delegate().
Traits
- Delegate
Ring - Trait to simplify implementing newtype-pattern for rings.
When you want to create a ring that just wraps another ring,
possibly adding some functionality, you can implement
DelegateRinginstead ofRingBase, and just provide how to map elements in the new ring to the wrapped ring and vice versa. - Delegate
Ring Impl Euclidean Ring - Marks a
DelegateRingRto be considered in the blanket implementationR: EuclideanRing where R::Base: EuclideanRingandR: PrincipalIdealRing where R::Base: PrincipalIdealRing. - Delegate
Ring Impl Finite Ring - Marks a
DelegateRingRto be considered in the blanket implementationR: FiniteRing where R::Base: FiniteRing.