pub struct WrapHom<R, S>{ /* private fields */ }Expand description
Homomorphism from a ring to a DelegateRing with the former ring
as delegate target. An element is mapped by using DelegateRing::rev_delegate().
Implementations
Sourceimpl<'a, R> WrapHom<RingRef<'a, R::Base>, RingRef<'a, R>>where
R: ?Sized + DelegateRing,
impl<'a, R> WrapHom<RingRef<'a, R::Base>, RingRef<'a, R>>where
R: ?Sized + DelegateRing,
Sourcepub fn to_delegate_ring(to: &'a R) -> Self
pub fn to_delegate_ring(to: &'a R) -> Self
Creates a new WrapHom from the given ring’s delegate target
to the given ring.
This function must take to by reference, since it must be able to
obtain a reference to its delegate target that lives long enough.