Contains the trait field::Field for rings that are fields.
Modules
- generic_
tests generic_tests
Traits
- Field
- Trait for rings that are fields, i.e. where every nonzero element has an inverse.
- Field
Store - Trait for
RingStores that storeFields. Mainly used to provide a convenient interface to theField-functions. - Perfect
Field - Field such that every finite degree extension field is separable.