pub type AddGroup<R: RingStore> = GroupValue<AddGroupBase<R>>;Available on crate feature
unstable-enable only.Expand description
AbelianGroupStore corresponding to AddGroupBase.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Aliased Type
pub struct AddGroup<R: RingStore> { /* private fields */ }