pub type MultGroup<R: RingStore> = GroupValue<MultGroupBase<R>>;unstable-enable only.Expand description
AbelianGroupStore corresponding to MultGroupBase.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Aliased Type
pub struct MultGroup<R: RingStore> { /* private fields */ }Implementations
Sourceimpl<R: RingStore> MultGroup<R>
impl<R: RingStore> MultGroup<R>
Sourcepub fn new(ring: R) -> Self
pub fn new(ring: R) -> Self
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn underlying_ring(&self) -> &R
pub fn underlying_ring(&self) -> &R
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn from_ring_el(&self, x: El<R>) -> Option<MultGroupEl<R>>
pub fn from_ring_el(&self, x: El<R>) -> Option<MultGroupEl<R>>
If x is contained in R*, returns a MultGroupEl representing
x. Otherwise, None is returned.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn as_ring_el<'a>(&self, x: &'a MultGroupEl<R>) -> &'a El<R>
pub fn as_ring_el<'a>(&self, x: &'a MultGroupEl<R>) -> &'a El<R>
Returns the ring element represented by the given group element.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.