pub struct LambdaHom<R: RingStore, S: RingStore, F>{ /* private fields */ }Expand description
A homomorphism between rings R -> S, with its action on elements
defined by a user-provided closure.
It is up to the user to ensure that the given closure indeed satisfies the ring homomorphism axioms:
- For
x, y in R, it should satisfyf(x) + f(y) = f(x + y) - For
x, y in R, it should satisfyf(x) * f(y) = f(x * y) - It should map
f(0) = 0andf(1) = 1
Hence, a LambdaHom should only be used if none of the builtin
homomorphisms can achieve the same result, since a function that does
not follow the above axioms will make algorithms misbehave, and can
lead to hard-to-debug errors.
Implementations
Sourceimpl<R: RingStore, S: RingStore, F> LambdaHom<R, S, F>
impl<R: RingStore, S: RingStore, F> LambdaHom<R, S, F>
Sourcepub fn new(from: R, to: S, f: F) -> Self
pub fn new(from: R, to: S, f: F) -> Self
Creates a new LambdaHom from from to to, mapping elements as
specified by the given function.
It is up to the user to ensure that the given closure indeed satisfies the ring homomorphism axioms:
- For
x, y in R, it should satisfyf(x) + f(y) = f(x + y) - For
x, y in R, it should satisfyf(x) * f(y) = f(x * y) - It should map
f(0) = 0andf(1) = 1
Hence, a LambdaHom should only be used if none of the builtin
homomorphisms can achieve the same result, since a function that does
not follow the above axioms will make algorithms misbehave, and can
lead to hard-to-debug errors.
Sourcepub fn into_domain_codomain(self) -> (R, S)
Available on crate feature unstable-enable only.
pub fn into_domain_codomain(self) -> (R, S)
unstable-enable only.Returns the stored domain and codomain rings, consuming this object.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.