Contains the trait pid::PrincipalIdealRing for rings in whom every ideal is principal.
Also contains pid::EuclideanRing, which is the simplest way how a ring can become a
principal idea ring.
Modules
- generic_
tests generic_tests
Traits
- Euclidean
Ring - Trait for rings that support euclidean division.
- Euclidean
Ring Store RingStoreforEuclideanRings- Principal
Ideal Ring - Trait for rings that are principal ideal rings, i.e. every ideal is generated by a single element.
- Principal
Ideal Ring Store - Trait for
RingStores that storePrincipalIdealRings. Mainly used to provide a convenient interface to thePrincipalIdealRing-functions.