Contains the core traits of the library - ring::RingBase and ring::RingStore.
Modules
- generic_
tests generic_tests
Structs
- Ring
Element Display Wrapper - Wrapper around a ring and one of its elements that implements
std::fmt::Displayand will print the element. Used byRingStore::format(). - RingRef
- The second most basic
crate::ring::RingStore. Similarly tocrate::ring::RingValueit is just a no-op container. - Ring
Value - The most fundamental
crate::ring::RingStore. It is basically a no-op container, i.e. stores acrate::ring::RingBaseobject by value, and allows accessing it.
Enums
- EnvBinding
Strength - Describes the context in which to print an algebraic expression. It is usually used to determine when to use parenthesis during printing.
Traits
- Hashable
ElRing - Trait for rings that can compute hashes for their elements.
This should be compatible with
RingBase::eq_elin the usual way. - Hashable
ElRing Store RingStoreforHashableElRings- Ring
Base - Basic trait for objects that have a ring structure. This trait is implementor-facing, so designed to be used for implementing new rings.
- Ring
Extension - Trait for rings that are an extension ring of a base ring. This does not have to be a proper extension in the mathematical sense, but is in some cases implemented for a wrapper of a ring object that represents the same ring.
- Ring
Extension Store RingStoreforRingExtensions- Ring
Store - Basic trait for objects that store (in some sense) a ring. It can also
be considered the user-facing trait for rings, so rings are always supposed
to be used through a
RingStore-object.
Type Aliases
- El
- Alias for
<<Self as RingStore>::Type as RingBase>::Element.