pub enum EnvBindingStrength {
Weakest,
Sum,
Product,
Power,
Strongest,
}Expand description
Describes the context in which to print an algebraic expression. It is usually used to determine when to use parenthesis during printing.
Example
struct CustomDisplay<'a>(&'a DensePolyRing<StaticRing<i64>>, &'a El<DensePolyRing<StaticRing<i64>>>, EnvBindingStrength);
impl<'a> std::fmt::Display for CustomDisplay<'a> {
fn fmt(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
self.0.get_ring().dbg_within(self.1, formatter, self.2)
}
}
let poly_ring = DensePolyRing::new(StaticRing::<i64>::RING, "X");
let f = poly_ring.add(poly_ring.one(), poly_ring.indeterminate());
assert_eq!("X + 1", format!("{}", CustomDisplay(&poly_ring, &f, EnvBindingStrength::Weakest)));
assert_eq!("X + 1", format!("{}", CustomDisplay(&poly_ring, &f, EnvBindingStrength::Sum)));
assert_eq!("(X + 1)", format!("{}", CustomDisplay(&poly_ring, &f, EnvBindingStrength::Product)));
assert_eq!("(X + 1)", format!("{}", CustomDisplay(&poly_ring, &f, EnvBindingStrength::Power)));
assert_eq!("(X + 1)", format!("{}", CustomDisplay(&poly_ring, &f, EnvBindingStrength::Strongest)));Variants
Weakest
The weakest possible binding strength, i.e. never add parenthesis.
Sum
Binding strength of addition (and subtraction), i.e. only add parenthesis
if the expression includes an operation that binds weaker than + (I cannot
think of any example, this seems to be a rare situation).
Product
Binding strength of multiplication (and division), i.e. only add parenthesis if
the expression includes an operation that binds weaker than * (Standard example
would be +).
Power
Binding strength of powering, i.e. only add parenthesis if the expression
includes an operation that binds weaker than exponentiation (Standard examples would
be + or *).
Strongest
The strongest possible binding strength, i.e. always add parenthesis.