pub struct NotEnoughPrecision;Available on crate feature
unstable-enable only.Expand description
Zero-sized struct that can be used as error value to indicate that
the currently used ApproxRealField does not have sufficient precision
to perform the demanded computation.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.