pub struct FreeAlgebraHom<R, S>where
R: RingStore,
R::Type: FreeAlgebra,
S: RingStore,
S::Type: FreeAlgebra,
<S::Type as RingExtension>::BaseRing: RingStore<Type = <<R::Type as RingExtension>::BaseRing as RingStore>::Type>,{ /* private fields */ }unstable-enable only.Expand description
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations
Sourceimpl<R> FreeAlgebraHom<R, R>
impl<R> FreeAlgebraHom<R, R>
Sourceimpl<R, S> FreeAlgebraHom<R, S>where
R: RingStore,
R::Type: FreeAlgebra,
S: RingStore,
S::Type: FreeAlgebra,
<S::Type as RingExtension>::BaseRing: RingStore<Type = <<R::Type as RingExtension>::BaseRing as RingStore>::Type>,
impl<R, S> FreeAlgebraHom<R, S>where
R: RingStore,
R::Type: FreeAlgebra,
S: RingStore,
S::Type: FreeAlgebra,
<S::Type as RingExtension>::BaseRing: RingStore<Type = <<R::Type as RingExtension>::BaseRing as RingStore>::Type>,
Sourcepub fn promise_is_well_defined(
from: R,
to: S,
image_of_generator: El<S>,
) -> Self
pub fn promise_is_well_defined( from: R, to: S, image_of_generator: El<S>, ) -> Self
Creates a new FreeAlgebraHom from R to S, mapping the canonical
generator of R to the given element of S. This assumes that the resulting
homomorphism is well-defined, i.e. the generating polynomial of R evaluated
at image_of_generator gives zero in S.
The checked variant of this function is FreeAlgebraHom::new().
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn new(from: R, to: S, image_of_generator: El<S>) -> Self
pub fn new(from: R, to: S, image_of_generator: El<S>) -> Self
Creates a new FreeAlgebraHom from R to S, mapping the canonical
generator of R to the given element of S.
As opposed to FreeAlgebraHom::promise_is_well_defined(), this function
checks that the resulting homomorphism is well-defined.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Sourcepub fn destruct(self) -> (R, S, El<S>)
pub fn destruct(self) -> (R, S, El<S>)
Consumes this object, producing the domain ring store, the codomain ring store and the image of the canonical generator of the domain number field.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.