pub struct AsFieldBase<R: RingStore>where
R::Type: DivisibilityRing,{ /* private fields */ }Expand description
A wrapper around a ring that marks this ring to be a perfect field. In particular,
the functions provided by DivisibilityRing will be used to provide
field-like division for the wrapped ring.
Example
A common case where you might encounter AsFieldBase is when working with rings
which might or might not be a field depending on data only known at runtime. One
example are implementations of ZnRing with modulus chosen at runtime.
// 7 is a prime, so this is a field - but must be checked at runtime
let Fp_as_ring = Zn::new(7);
// we use `ZnRing::as_field()` to make this a field
let Fp_as_field: AsField<Zn> = Fp_as_ring.as_field().ok().unwrap();
// in many cases (like here) we can use canonical isomorphisms to map elements
let iso = Fp_as_field.can_iso(&Fp_as_ring).unwrap();
assert_el_eq!(&Fp_as_ring, Fp_as_ring.one(), iso.map(Fp_as_field.one()));Since the canonical isomorphisms are not given by blanket implementations
(unfortunately there are some conflicts…), they are often not available in
generic contexts. In this case, the currently best solution is to directly
use the functions given by DelegateRing, e.g.
fn work_in_Fp<R>(ring: R)
where R: RingStore,
R::Type: ZnRing
{
use crate::feanor_math::delegate::DelegateRing;
let R_as_field = (&ring).as_field().ok().unwrap();
let x = ring.one();
// since `DelegateRing` does not have a corresponding `RingStore`, the access
// through `get_ring()` is necessary
let x_mapped = R_as_field.get_ring().rev_delegate(x);
let x_mapped_back = R_as_field.get_ring().delegate(x_mapped);
}Implementations
Sourceimpl<R: RingStore> AsFieldBase<R>where
R::Type: DivisibilityRing,
impl<R: RingStore> AsFieldBase<R>where
R::Type: DivisibilityRing,
Sourcepub fn promise_is_perfect_field(base: R) -> Self
pub fn promise_is_perfect_field(base: R) -> Self
Assumes that the given ring is a perfect field, and wraps it in AsFieldBase.
This function is not really unsafe, but users should be careful to only use it with rings that are perfect fields. This cannot be checked in here, so must be checked by the caller.
Sourcepub fn promise_is_field(base: R) -> Result<Self, R>where
R::Type: FiniteRingSpecializable,
Available on crate feature unstable-enable only.
pub fn promise_is_field(base: R) -> Result<Self, R>where
R::Type: FiniteRingSpecializable,
unstable-enable only.Assumes that the given ring is a field and checks whether it is perfect. If this is the case,
the function wraps it in AsFieldBase.
This function is not really unsafe, but users should be careful to only use it with rings that are fields. This cannot be checked in here, so must be checked by the caller.
Note that this function does check that the passed field is perfect. However,
that check is too conservative, and might fail on some perfect fields.
If you are sure that the field is also perfect, consider using AsFieldBase::promise_is_perfect_field()
instead.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
pub fn unwrap_element(&self, el: <Self as RingBase>::Element) -> El<R>
Sourcepub fn unwrap_self(self) -> R
pub fn unwrap_self(self) -> R
Removes the wrapper, returning the underlying base field.
Sourceimpl<R: RingStore> AsFieldBase<R>where
R::Type: PerfectField,
impl<R: RingStore> AsFieldBase<R>where
R::Type: PerfectField,
Sourcepub fn from_field(base: R) -> Self
pub fn from_field(base: R) -> Self
Creates a new AsFieldBase from a ring that is already known to be a
perfect field.