Function permute_using_allocator

pub fn permute_using_allocator<V, T, F, A: Allocator>(
    values: V,
    perm: F,
    allocator: A,
)
where V: SwappableVectorViewMut<T>, F: Fn(usize) -> usize,
Computes values_new[i] = values[perm(i)].

Availability

This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.