Contains the trait serialization::SerializableElementRing for rings whose elements can be serialized
by using serde.
It also contains some utilities to simplify this, since it is usually not possible to use
#[derive(Serialize, Deserialize)] to implement serialization - the reason is that serialization and
deserialization usually require access to the ring. Hence, we need to use serde::de::DeserializeSeed,
but this is incompatible with #[derive]
Modules
- generic_
tests - Availability
Structs
- Deserialize
Seed Newtype - Availability
- Deserialize
Seed Seq - A
DeserializeSeedthat deserializes a sequence by deserializing every element according to some derivedDeserializeSeed. The resulting elements are collected using a custom reducer function, akin toIterator::fold(). - Deserialize
With Ring - Wrapper of a ring that implements [
serde::DeserializationSeed] by trying to deserialize an element w.r.t. the wrapped ring. - Serializable
Newtype - Availability
- Serializable
Seq - Wraps a
VectorFnwhose elements areSerializeable, and allows to serialize all elements as a sequence. - Serialize
Owned With Ring - Wraps a ring and a one of its elements. Implements
serde::Serializeand will serialize the element w.r.t. the ring. - Serialize
With Ring - Wraps a ring and a reference to one of its elements. Implements
serde::Serializeand will serialize the element w.r.t. the ring.
Traits
- Serializable
Element Ring - Trait for rings whose elements can be serialized.