Available on crate feature
unstable-enable only.Expand description
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Functions
- test_
serialization - Availability
- test_
serialize_ deserialize - Availability