pub trait FiniteRingOperation<R>where
R: ?Sized,{
type Output;
// Required methods
fn execute(self) -> Self::Output
where R: FiniteRing;
fn fallback(self) -> Self::Output;
}Available on crate feature
unstable-enable only.Expand description
Operation on a ring R that only makes sense if R implements
the trait crate::rings::finite::FiniteRing.
Used through the trait FiniteRingSpecializable.
Availability
This API is marked as unstable and is only available when the unstable-enable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Required Associated Types
Required Methods
Sourcefn execute(self) -> Self::Outputwhere
R: FiniteRing,
fn execute(self) -> Self::Outputwhere
R: FiniteRing,
Runs the operations, with the additional assumption that R: FiniteRing.
Sourcefn fallback(self) -> Self::Output
fn fallback(self) -> Self::Output
Runs the operation in case that R is not a FiniteRing.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".